aboutsummaryrefslogtreecommitdiffstats
path: root/build/scripts/create_recursive_library_for_cmake.py
diff options
context:
space:
mode:
authorsennikovmv <sennikovmv@yandex-team.com>2024-02-16 10:14:01 +0300
committerInnokentii Mokin <innokentii@ydb.tech>2024-02-17 11:32:12 +0000
commit09824efb0099bc4ca1905ed041fb4a9df330825c (patch)
tree3ce1b0635fb5b3fb2c6db82928160ddc31f46db8 /build/scripts/create_recursive_library_for_cmake.py
parent7def9975db05a4c70cbfb8c9713199fcbcc5aecb (diff)
downloadydb-09824efb0099bc4ca1905ed041fb4a9df330825c.tar.gz
Yexport test
42477b361df98bfa4ad9fa98d79ee8c6e27a78ef
Diffstat (limited to 'build/scripts/create_recursive_library_for_cmake.py')
-rw-r--r--build/scripts/create_recursive_library_for_cmake.py6
1 files changed, 3 insertions, 3 deletions
diff --git a/build/scripts/create_recursive_library_for_cmake.py b/build/scripts/create_recursive_library_for_cmake.py
index 11c80fb0d2..5be06dc37b 100644
--- a/build/scripts/create_recursive_library_for_cmake.py
+++ b/build/scripts/create_recursive_library_for_cmake.py
@@ -46,7 +46,7 @@ class Opts(object):
self.preserved_options = []
# these variables can contain paths absolute or relative to CMAKE_BINARY_DIR
self.global_libs_and_objects_input = []
self.non_global_libs_input = []
self.output = None
@@ -57,7 +57,7 @@ class Opts(object):
(these use absolute paths).
If it is a library that is added from some other path (like CUDA) return True
"""
- return not (os.path.exists(path) or os.path.exists(os.path.join(self.parsed_args.cmake_binary_dir, path)))
+ return not (os.path.exists(path) or os.path.exists(os.path.join(self.parsed_args.project_binary_dir, path)))
def process_input(args):
i = 0
@@ -143,7 +143,7 @@ class FilesCombiner(object):
archiver_tool_path,
arch_type,
'gnu', # llvm_ar_format, used only if arch_type == 'LLVM_AR'
- opts.parsed_args.cmake_binary_dir,
+ opts.parsed_args.project_binary_dir,
'None', # plugin. Unused for now
]
# the remaining archiving cmd args are [output, .. input .. ]
@@ -46,7 +46,7 @@ class Opts(object):
self.preserved_options = []
- # these variables can contain paths absolute or relative to CMAKE_BINARY_DIR
+ # these variables can contain paths absolute or relative to project_binary_dir
self.global_libs_and_objects_input = []
self.non_global_libs_input = []